@@ -30,6 +30,7 @@
 #include <core/testing/cross_process_sync.h>
 #include <core/testing/fork_and_run.h>
 
+#include <boost/asio.hpp>
 #include <gtest/gtest.h>
 
 namespace dbus = core::dbus;
@@ -54,6 +55,8 @@ struct ChaosMonkey
 
 struct Executor : public core::dbus::testing::Fixture
 {
+ protected:
+    boost::asio::io_service io_service;
 };
 
 auto session_bus_config_file =
@@ -67,13 +70,13 @@ auto system_bus_config_file =
 
 TEST_F(Executor, ThrowsOnConstructionFromNullBus)
 {
-    EXPECT_ANY_THROW(core::dbus::asio::make_executor(core::dbus::Bus::Ptr{}));
+    EXPECT_ANY_THROW(core::dbus::asio::make_executor(core::dbus::Bus::Ptr{}, io_service));
 }
 
 TEST_F(Executor, DoesNotThrowForExistingBus)
 {
     auto bus = session_bus();
-    EXPECT_NO_THROW(bus->install_executor(core::dbus::asio::make_executor(bus)));
+    EXPECT_NO_THROW(bus->install_executor(core::dbus::asio::make_executor(bus, io_service)));
 }
 
 TEST_F(Executor, ABusRunByAnExecutorReceivesSignals)
@@ -85,7 +88,7 @@ TEST_F(Executor, ABusRunByAnExecutorReceivesSignals)
     {
         core::testing::SigTermCatcher sc;
         auto bus = session_bus();
-        bus->install_executor(dbus::asio::make_executor(bus));
+        bus->install_executor(dbus::asio::make_executor(bus, io_service));
         auto service = dbus::Service::add_service<test::Service>(bus);
         auto skeleton = service->add_object_for_path(dbus::types::ObjectPath("/this/is/unlikely/to/exist/Service"));
         skeleton->install_method_handler<test::Service::Method>(
@@ -114,7 +117,7 @@ TEST_F(Executor, ABusRunByAnExecutorReceivesSignals)
     auto client = [this, expected_value, &cross_process_sync]() -> core::posix::exit::Status
     {
         auto bus = session_bus();
-        bus->install_executor(dbus::asio::make_executor(bus));
+        bus->install_executor(dbus::asio::make_executor(bus, io_service));
         std::thread t{[bus](){bus->run();}};
         
         EXPECT_EQ(std::uint32_t(1), cross_process_sync.wait_for_signal_ready_for(std::chrono::milliseconds{500}));
@@ -153,7 +156,7 @@ TEST_F(Executor, TimeoutsAreHandledCorrectly)
         ChaosMonkey chaos_monkey;
         core::testing::SigTermCatcher sc;
         auto bus = session_bus();
-        bus->install_executor(dbus::asio::make_executor(bus));
+        bus->install_executor(dbus::asio::make_executor(bus, io_service));
         auto service = dbus::Service::add_service<test::Service>(bus);
         auto skeleton = service->add_object_for_path(dbus::types::ObjectPath("/this/is/unlikely/to/exist/Service"));
         skeleton->install_method_handler<test::Service::Method>(
@@ -190,7 +193,7 @@ TEST_F(Executor, TimeoutsAreHandledCorrectly)
     auto client = [this, expected_value, &cross_process_sync]() -> core::posix::exit::Status
     {
         auto bus = session_bus();
-        bus->install_executor(dbus::asio::make_executor(bus));
+        bus->install_executor(dbus::asio::make_executor(bus, io_service));
         std::thread t{[bus](){bus->run();}};
 
         // If you encounter failures in the client, uncomment the following two lines
@@ -260,8 +263,6 @@ TEST_F(Executor, TimeoutsAreHandledCorrectly)
     EXPECT_EQ(core::testing::ForkAndRunResult::empty, core::testing::fork_and_run(service, client));
 }
 
-
-
 /*TEST(Bus, TimeoutThrowsForNullDBusWatch)
 {
     boost::asio::io_service io_service;
