@@ -82,11 +82,25 @@ TEST_F(Service, AddingServiceAndObjectAndCallingIntoItSucceeds)
             auto writable_property = skeleton->get_property<test::Service::Properties::Dummy>();
             writable_property->set(expected_value);
 
-            skeleton->install_method_handler<test::Service::Method>([bus, skeleton, expected_value](const dbus::Message::Ptr& msg)
+            auto readonly_property = skeleton->get_property<test::Service::Properties::ReadOnly>();
+            readonly_property->set(7);
+
+            skeleton->install_method_handler<test::Service::Method>([bus, skeleton, &readonly_property, expected_value](const dbus::Message::Ptr& msg)
             {
                 auto reply = dbus::Message::make_method_return(msg);
                 reply->writer() << expected_value;
                 bus->send(reply);
+
+                readonly_property->set(expected_value);
+                auto changed_signal = skeleton->get_signal<core::dbus::interfaces::Properties::Signals::PropertiesChanged>();
+                core::dbus::interfaces::Properties::Signals::PropertiesChanged::ArgumentType
+                        args("this.is.unlikely.to.exist.Service",
+                             {{test::Service::Properties::ReadOnly::name(),
+                               core::dbus::types::TypedVariant<test::Service::Properties::ReadOnly::ValueType>(expected_value)}},
+                             {});
+                skeleton->emit_signal<core::dbus::interfaces::Properties::Signals::PropertiesChanged, core::dbus::interfaces::Properties::Signals::PropertiesChanged::ArgumentType>(args);
+                changed_signal->emit(args);
+
                 skeleton->emit_signal<test::Service::Signals::Dummy, int64_t>(expected_value);
             });
 
@@ -118,6 +132,14 @@ TEST_F(Service, AddingServiceAndObjectAndCallingIntoItSucceeds)
             {
                 std::cout << "Dummy property changed: " << d << std::endl;
             });
+
+            auto readonly_property = stub->get_property<test::Service::Properties::ReadOnly>();
+            EXPECT_EQ(readonly_property->get(), 7);
+            std::uint32_t changed_value = 0;
+            readonly_property->changed().connect([&changed_value](std::uint32_t value){
+                changed_value = value;
+            });
+
             auto signal = stub->get_signal<test::Service::Signals::Dummy>();
             int64_t received_signal_value = -1;
             signal->connect([bus, &received_signal_value](const int32_t& value)
@@ -144,6 +166,8 @@ TEST_F(Service, AddingServiceAndObjectAndCallingIntoItSucceeds)
                 t.join();
 
             EXPECT_EQ(expected_value, received_signal_value);
+            EXPECT_EQ(expected_value, readonly_property->get());
+            EXPECT_EQ(changed_value, expected_value);
 
             return ::testing::Test::HasFailure() ? core::posix::exit::Status::failure : core::posix::exit::Status::success;
         };
@@ -153,13 +177,64 @@ TEST_F(Service, AddingServiceAndObjectAndCallingIntoItSucceeds)
 
 TEST_F(Service, AddingANonExistingServiceDoesNotThrow)
 {
-    const std::string service_name
-    {
-        "very.unlikely.that.this.name.exists"
-    };
     ASSERT_NO_THROW(auto service = dbus::Service::add_service<test::Service>(session_bus()););
 }
 
+namespace
+{
+struct Dummy
+{
+    static const std::string& name()
+    {
+        static std::string s{"A.Dummy.Service"};
+        return s;
+    }
+};
+}
+
+// We cache service allocations in-process. For that, we rely on two child processes for testing purposes and
+// to check that trying to own a service name for the second name actually throws.
+TEST_F(Service, AddingAServiceTwiceThrows)
+{
+    // p1 --| Done accessing the service |--> p2
+    core::testing::CrossProcessSync first_process_acquired_name;
+    // p2 --| Done trying to access the service |--> p1
+    core::testing::CrossProcessSync second_process_acquired_name;
+
+    // This is the child process that owns the dummy service. It waits for the second process to
+    // come up and trying to own the same service on the same bus. Otherwise, the service object
+    // would go out of scope in P1 and clean up the owned name.
+    auto p1 = core::posix::fork([this, &first_process_acquired_name, &second_process_acquired_name]
+    {
+        core::dbus::Service::Ptr service;
+        EXPECT_NO_THROW(service = dbus::Service::add_service<Dummy>(session_bus()));
+        first_process_acquired_name.try_signal_ready_for(std::chrono::seconds{2});
+        second_process_acquired_name.wait_for_signal_ready_for(std::chrono::seconds{2});
+
+        return ::testing::Test::HasFailure() ? core::posix::exit::Status::failure : core::posix::exit::Status::success;
+    }, core::posix::StandardStream::empty);
+
+    auto p2 = core::posix::fork([this, &first_process_acquired_name, &second_process_acquired_name]
+    {
+        first_process_acquired_name.wait_for_signal_ready_for(std::chrono::seconds{2});
+
+        core::dbus::Service::Ptr service;
+        EXPECT_ANY_THROW(service = dbus::Service::add_service<Dummy>(session_bus()););
+        second_process_acquired_name.try_signal_ready_for(std::chrono::seconds{2});
+
+        return ::testing::Test::HasFailure() ? core::posix::exit::Status::failure : core::posix::exit::Status::success;
+    }, core::posix::StandardStream::empty);
+
+    core::posix::wait::Result r1 = p1.wait_for(core::posix::wait::Flags::untraced);
+    core::posix::wait::Result r2 = p2.wait_for(core::posix::wait::Flags::untraced);
+
+    EXPECT_EQ(core::posix::wait::Result::Status::exited, r1.status);
+    EXPECT_EQ(core::posix::exit::Status::success, r1.detail.if_exited.status);
+
+    EXPECT_EQ(core::posix::wait::Result::Status::exited, r2.status);
+    EXPECT_EQ(core::posix::exit::Status::success, r2.detail.if_exited.status);
+}
+
 TEST_F(Service, AddingAnExistingServiceThrowsForSpecificFlags)
 {
     const std::string service_name
